iamai package
=============

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   iamai.adapter
   iamai.model

Submodules
----------

.. toctree::
   :maxdepth: 4

   iamai.bot
   iamai.cli
   iamai.config
   iamai.const
   iamai.dependencies
   iamai.event
   iamai.exceptions
   iamai.i18n
   iamai.log
   iamai.message
   iamai.plugin
   iamai.typing
   iamai.utils

Module contents
---------------

.. automodule:: iamai
   :members:
   :undoc-members:
   :show-inheritance:
